Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(254)

Unified Diff: components/gcm_driver/gcm_stats_recorder_impl.h

Issue 1515153003: Enable chrome://gcm-internals on Android (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/gcm_driver/gcm_stats_recorder_impl.h
diff --git a/components/gcm_driver/gcm_stats_recorder_impl.h b/components/gcm_driver/gcm_stats_recorder_impl.h
index 1656bb8536bfaceb762fc4db084ff7bb0ae22ff5..390c1062232b872b0f0b417e25785d2ee05a6242 100644
--- a/components/gcm_driver/gcm_stats_recorder_impl.h
+++ b/components/gcm_driver/gcm_stats_recorder_impl.h
@@ -20,8 +20,8 @@
namespace gcm {
// Records GCM internal stats and activities for debugging purpose. Recording
// can be turned on/off by calling SetRecording(...) function. It is turned off
// by default.
// This class is not thread safe. It is meant to be owned by a gcm client
// instance.
class GCMStatsRecorderImpl : public GCMStatsRecorder {
@@ -29,14 +29,6 @@ class GCMStatsRecorderImpl : public GCMStatsRecorder {
GCMStatsRecorderImpl();
~GCMStatsRecorderImpl() override;
- // Indicates whether the recorder is currently recording activities or not.
- bool is_recording() const {
- return is_recording_;
- }
-
- // Turns recording on/off.
- void SetRecording(bool recording);
-
// Set a delegate to receive callback from the recorder.
void SetDelegate(Delegate* delegate);
@@ -94,8 +86,11 @@ class GCMStatsRecorderImpl : public GCMStatsRecorder {
const std::string& receiver_id,
const std::string& message_id) override;
- // Collect all recorded activities into the struct.
- void CollectActivities(RecordedActivities* recorder_activities) const;
+ // Collect all recorded activities into |*recorded_activities|.
+ void CollectActivities(RecordedActivities* recorded_activities) const;
+
+ bool is_recording() const { return is_recording_; }
+ void set_is_recording(bool recording) { is_recording_ = recording; }
const std::deque<CheckinActivity>& checkin_activities() const {
return checkin_activities_;
« no previous file with comments | « components/gcm_driver/gcm_stats_recorder_android_unittest.cc ('k') | components/gcm_driver/gcm_stats_recorder_impl.cc » ('j') | no next file with comments »
@@ -20,8 +20,8 @@
namespace gcm {
// Records GCM internal stats and activities for debugging purpose. Recording
-// can be turned on/off by calling SetRecording(...) function. It is turned off
-// by default.
+// can be turned on/off by calling set_is_recording(...) function. It is turned
+// off by default.
// This class is not thread safe. It is meant to be owned by a gcm client
// instance.

Powered by Google App Engine
This is Rietveld 408576698